library(testthat)
library(vlad)

#test_check("vlad")
